@@ -6,6 +6,7 @@ import ioc
 import unimatrix.lib.test
 from django.test import TestCase
 
+from ...models import Blob
 from ..blobfactory import BlobFactory
 
 
@@ -14,13 +15,14 @@ class BlobFactoryTestCase(TestCase):
     @ioc.inject('svc', 'BlobEncryptionKeyService')
     def setUp(self, svc):
         self.factory = BlobFactory()
+        self.model = Blob
         svc.generate()
 
     def test_new_plaintext(self):
         pt = b'Hello world!'
         with tempfile.NamedTemporaryFile('w+b') as f:
             f.write(pt)
-            blob = self.factory.new(f, "text/plain")
+            blob = self.factory.new(self.model, f, "text/plain")
             f.seek(0)
             self.assertEqual(pt, f.read())
 
@@ -28,7 +30,7 @@ class BlobFactoryTestCase(TestCase):
         pt = b'Hello world!'
         with tempfile.NamedTemporaryFile('w+b') as f:
             f.write(pt)
-            blob = self.factory.new(f, "text/plain", encrypt=True)
+            blob = self.factory.new(self.model, f, "text/plain", encrypt=True)
             f.seek(0)
             self.assertNotEqual(pt, f.read())
 
@@ -37,7 +39,7 @@ class BlobFactoryTestCase(TestCase):
         pt = os.urandom(16)
         with tempfile.NamedTemporaryFile('w+b') as f:
             f.write(pt)
-            blob = self.factory.new(f, "text/plain", encrypt=True)
+            blob = self.factory.new(self.model, f, "text/plain", encrypt=True)
             f.seek(0)
             self.assertNotEqual(pt, f.read())
 
