@@ -23,3 +23,9 @@ class GoogleCloudStorageBackendTestCase(test_local.LocalDiskBackendTestCase):
         return {
             'base_path': os.path.join('tmp', bytes.hex(os.urandom(16)))
         }
+
+    def test_update_labels(self):
+        labels = {}
+        self.backend.update_labels(labels)
+        self.assertIn('cloud.google.com/project', labels)
+        self.assertIn('storage.googleapis.com/bucket', labels)
